'use strict';

var a = 'a',
    b = 'b';

assert.equal( a, 'a' );
assert.equal( b, 'b' );
